@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dbus
 version: 0.10.12
-id: dbus-0.10.12-f6f03c921bc449e06e2b31ac6de64e68
-key: dbus_Eqk01E7fBc5AtpaXg4XE0I
+id: dbus-0.10.12-8a56715ad4c74b16585ed43d4af51957
+key: dbus_IxhwGZlgsulHkLCLPloWKa
 license: GPL-3
 maintainer: John Millikin <john@john-millikin.com>
 stability: experimental
@@ -70,7 +70,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dbus-0.10.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dbus-0.10.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dbus-0.10.12
-hs-libraries: HSdbus-0.10.12-Eqk01E7fBc5AtpaXg4XE0I
+hs-libraries: HSdbus-0.10.12-IxhwGZlgsulHkLCLPloWKa
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -78,7 +78,7 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     libxml-sax-0.7.5-5224794631ed64ec66d4738f6368afe2
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
